@@ -1,6 +1,7 @@
 import logging
 
 import click
+
 from .greppo import GreppoApp
 from .greppo_server import GreppoServer
 
@@ -8,7 +9,9 @@ from .greppo_server import GreppoServer
 @click.command()
 @click.argument("command")
 @click.argument("path_to_script")
-def wrap_and_run_script(command, path_to_script: str):
+@click.argument("host")
+@click.argument("port")
+def wrap_and_run_script(command, path_to_script, host, port):
     """Run a Greppo COMMAND with PATH_TO_SCRIPT_NAME
 
     PATH_TO_SCRIPT is the path to the script
@@ -18,7 +21,7 @@ def wrap_and_run_script(command, path_to_script: str):
         gpo = GreppoApp()
         server = GreppoServer(gr_app=gpo, user_script=path_to_script)
 
-        server.run()
+        server.run(host=host, port=int(port))
     else:
         logging.error("Command {} not supported".format(command))
 
